extract_names: Extract the Names of the Variables

View source: R/extract_names.R

extract_namesR Documentation

Extract the Names of the Variables

Description

The function extracts the names of the variables from the data set used in the analysis and places them in a vector.

Usage

extract_names(df)

Arguments

df

Data frame with data for the analysis.

Value

A vector with names of the variables.

Examples


 df <- badp::economic_growth

 reg_names <- extract_names(df)



badp documentation built on Sept. 15, 2026, 1:08 a.m.