| migration_model_space_nonnested | R Documentation |
optim_model_space in the case of migration data obtained with nonnested approach.A badp_model_space object created with optim_model_space using the
migration_data dataset with nonnested approach.
migration_model_space_nonnested
An object of class badp_model_space:
A numeric matrix with 51 rows and 16 columns, containing parameter values for the full model space. Each column represents a different model.
A numeric matrix of statistics computed by
compute_model_space_stats based on params, with one
column per model. Row 1 holds the maximized log-likelihood. Row 2 holds
the marginal likelihood approximation used to weight the models,
exp((loglik - (k/2) * log(N * T)) / N); note that it is not a BIC.
There follow K rows of standard deviations and K rows of
robust standard deviations, where K is the number of regressors
including the lagged dependent variable. The final three rows hold
tr(H^-1 J), the dimension of the parameter vector and the
numerical rank of J; see score_rank.
A character vector with the names of the variables.
The total number of observations in the panel (1012).
The data frame used in the analysis.
A logical indicating whether the model space uses nested specifications.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.