n_models: Size of the Model Space

View source: R/accessors.R

n_modelsR Documentation

Size of the Model Space

Description

Returns the number of models over which the averaging is performed. The lagged dependent variable enters every model and is never averaged over, so the count is two to the power of length(regressors(x)), not of the total number of columns.

Usage

n_models(x, ...)

## S3 method for class 'badp_bma'
n_models(x, ...)

## S3 method for class 'badp_model_space'
n_models(x, ...)

Arguments

x

An object of class badp_bma or badp_model_space.

...

Arguments passed to methods.

Value

A single integer.

See Also

bma, optim_model_space

Examples


data(full_model_space)
n_models(full_model_space)



badp documentation built on Sept. 15, 2026, 1:08 a.m.