plot.badp_best_models: Plot a Best-Models Selection

plot.badp_best_modelsR Documentation

Plot a Best-Models Selection

Description

Draws the inclusion table or the table of estimates for the selected models to the active graphics device.

Usage

## S3 method for class 'badp_best_models'
plot(x, which = c("estimates", "inclusion"), robust = FALSE, ...)

Arguments

x

An object of class badp_best_models.

which

Which table to draw: "estimates" (the default) or "inclusion".

robust

Logical. If TRUE, robust standard errors are used in the table of estimates.

...

Additional arguments (currently unused).

Value

Invisibly returns the drawn table.

See Also

best_models, print.badp_best_models

Examples

data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)

plot(best)
plot(best, which = "inclusion")


badp documentation built on Sept. 15, 2026, 1:08 a.m.