print.badp_best_models: Print a Best-Models Selection

print.badp_best_modelsR Documentation

Print a Best-Models Selection

Description

Prints, to the console, which regressors enter each of the selected models together with their posterior model probabilities.

Usage

## S3 method for class 'badp_best_models'
print(x, ...)

Arguments

x

An object of class badp_best_models.

...

Additional arguments (currently unused).

Value

Invisibly returns x.

See Also

best_models, summary.badp_best_models, plot.badp_best_models

Examples

data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)

best


badp documentation built on Sept. 15, 2026, 1:08 a.m.