print.badp_model: Print a Single Model

print.badp_modelR Documentation

Print a Single Model

Description

Prints the regressors included in one of the best models together with its posterior model probability and its coefficient table.

Usage

## S3 method for class 'badp_model'
print(x, robust = FALSE, ...)

Arguments

x

An object of class badp_model.

robust

Logical. If TRUE, robust standard errors are shown.

...

Additional arguments (currently unused).

Value

Invisibly returns x.

See Also

best_models, summary.badp_model

Examples

data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)

best[[1]]
print(best[[1]], robust = TRUE)


badp documentation built on Sept. 15, 2026, 1:08 a.m.