print.badp_model_space: Print Model Space Object

View source: R/s3_methods_model_space.R

print.badp_model_spaceR Documentation

Print Model Space Object

Description

Print method for objects of class badp_model_space.

Usage

## S3 method for class 'badp_model_space'
print(x, ...)

Arguments

x

An object of class badp_model_space, typically the result of optim_model_space.

...

Additional arguments forwarded to summary.badp_model_space.

Details

This method is a thin wrapper that delegates to summary.badp_model_space and then prints the resulting summary, so print(x) and print(summary(x)) produce identical output.

Value

Invisibly returns the input object x.

See Also

summary.badp_model_space, optim_model_space, bma

Examples


data(full_model_space)
print(full_model_space)



badp documentation built on Aug. 20, 2026, 9:08 a.m.