regressors: Names of the Regressors

View source: R/accessors.R

regressorsR Documentation

Names of the Regressors

Description

Returns the names of the regressors considered in the analysis.

Usage

regressors(x, ...)

## S3 method for class 'badp_bma'
regressors(x, include_lagged = FALSE, ...)

## S3 method for class 'badp_model_space'
regressors(x, include_lagged = FALSE, ...)

Arguments

x

An object of class badp_bma or badp_model_space.

...

Arguments passed to methods.

include_lagged

Logical. Include the lagged dependent variable, which is the first name and enters every model. Defaults to FALSE.

Value

A character vector of regressor names.

See Also

bma, optim_model_space

Examples


data(full_model_space)
regressors(full_model_space)
regressors(full_model_space, include_lagged = TRUE)



badp documentation built on Sept. 15, 2026, 1:08 a.m.