residual_maker_matrix: Residual Maker Matrix

View source: R/SEM_param_matrices.R

residual_maker_matrixR Documentation

Residual Maker Matrix

Description

Computes the residual maker matrix, i.e. a matrix M such that given a matrix X and a vector Y the vector of residuals from the regression of Y on X is given by M * Y

Usage

residual_maker_matrix(m)

Arguments

m

matrix based on which the residual maker matrix is built

Value

Residual maker matrix

Examples

residual_maker_matrix(matrix(c(1,2,3,4), nrow = 2))


badp documentation built on Sept. 15, 2026, 1:08 a.m.