sem_C_matrix: Matrix with alpha, beta, phi_0 and phi_1 parameters for SEM...

View source: R/SEM_param_matrices.R

sem_C_matrixR Documentation

Matrix with alpha, beta, phi_0 and phi_1 parameters for SEM representation

Description

Matrix which describes linear dependencies between the dependent variable and the initial values of the dependent variable and the regressors within the SEM representation.

Usage

sem_C_matrix(alpha, phi_0, n_periods, beta = NULL, phi_1 = NULL)

Arguments

alpha

numeric

phi_0

numeric

n_periods

integer

beta

numeric vector. Default is NULL for no regressors case.

phi_1

numeric vector. Default is NULL for no regressors case.

Value

Matrix with linear dependencies for initial conditions

Examples

alpha <- 9
phi_0 <- 19
beta <- 11:15
phi_1 <- 21:25
n_periods <- 4
sem_C_matrix(alpha, phi_0, n_periods, beta, phi_1)


badp documentation built on Aug. 20, 2026, 9:08 a.m.