sem_sigma_matrix: Matrices with the sigma parameters for SEM representation

View source: R/SEM_param_matrices.R

sem_sigma_matrixR Documentation

Matrices with the sigma parameters for SEM representation

Description

Matrices which describe the covariance structure within the SEM representation.

Usage

sem_sigma_matrix(err_var, dep_vars, phis = NULL, psis = NULL)

Arguments

err_var

numeric error variance parameter

dep_vars

double vector with variance parameters of the dependent variable

phis

double vector with phi parameter values. Default is NULL for no regressors case.

psis

double vector with psi parameter values. Default is NULL for no regressors case.

Value

List with two matrices describing the covariance structure

Examples

err_var <- 1
dep_vars <- c(2, 2, 2, 2)
phis <- c(10, 10, 20, 20, 30, 30)
psis <- c(101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112)
sem_sigma_matrix(err_var, dep_vars, phis, psis)


badp documentation built on Aug. 20, 2026, 9:08 a.m.