sub-.badp_best_models: Subset a Best-Models Selection

[.badp_best_modelsR Documentation

Subset a Best-Models Selection

Description

Keeps the class and the attributes of the selection when a subset of the models is taken.

Usage

## S3 method for class 'badp_best_models'
x[i]

Arguments

x

An object of class badp_best_models.

i

Indices of the models to keep.

Value

An object of class badp_best_models.

Examples

data(small_model_space)
best <- best_models(bma(small_model_space), best = 5)

best[1:2]   # a badp_best_models object holding the two best models
best[[1]]   # a single badp_model


badp documentation built on Sept. 15, 2026, 1:08 a.m.