summary.badp_best_models: Summarize a Best-Models Selection

summary.badp_best_modelsR Documentation

Summarize a Best-Models Selection

Description

Summarize a Best-Models Selection

Usage

## S3 method for class 'badp_best_models'
summary(object, robust = FALSE, ...)

Arguments

object

An object of class badp_best_models.

robust

Logical. If TRUE, robust standard errors are shown in the table of estimates.

...

Additional arguments (currently unused).

Value

An object of class summary.badp_best_models holding the inclusion table, the table of formatted estimates, the posterior model probabilities and the regressors entering each model.

See Also

best_models, print.badp_best_models

Examples

data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)

summary(best)
summary(best, robust = TRUE)


badp documentation built on Sept. 15, 2026, 1:08 a.m.