| coef.badp_model | R Documentation |
Extracts the maximum likelihood estimates of one of the best models.
## S3 method for class 'badp_model'
coef(object, se = FALSE, include_absent = FALSE, digits = NULL, ...)
object |
An object of class |
se |
Logical. If |
include_absent |
Logical. If |
digits |
Number of decimal places to round the result to. By default
the values are returned exactly as estimated; supplying |
... |
Additional arguments (currently unused). |
A named numeric vector, or a matrix when se = TRUE.
best_models, summary.badp_model
data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)
coef(best[[1]])
coef(best[[1]], se = TRUE)
coef(best[[1]], se = TRUE, digits = 3)
coef(best[[1]], include_absent = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.