extract_names: Extraction of names of the variables

View source: R/extract_names.R

extract_namesR Documentation

Extraction of names of the variables

Description

The function extracts the names of the variables from the data set used in the analysis and places them in a vector.

Usage

extract_names(df)

Arguments

df

Data frame with data for the analysis.

Value

A vector with names of the variables.

Examples


 df <- badp::economic_growth

 reg_names <- extract_names(df)



badp documentation built on Aug. 20, 2026, 9:08 a.m.