View source: R/extract_names.R
| extract_names | R Documentation |
The function extracts the names of the variables from the data set used in the analysis and places them in a vector.
extract_names(df)
df |
Data frame with data for the analysis. |
A vector with names of the variables.
df <- badp::economic_growth
reg_names <- extract_names(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.