| init_model_space_params | R Documentation |
This function builds a representation of the model space, by creating a
dataframe where each column represents values of the parameters for a given
model. Real value means that the parameter is included in the model. A
parameter not present in the model is marked as NA.
init_model_space_params(df, timestamp_col, entity_col, dep_var_col, init_value)
df |
Data frame with data for the SEM analysis. |
timestamp_col |
Column which determines time periods. For now only natural numbers can be used as timestamps |
entity_col |
Column which determines entities (e.g. countries, people) |
dep_var_col |
Column with dependent variable |
init_value |
A function of one argument |
Currently the set of features is assumed to be all columns which remain after
excluding timestamp_col, entity_col and dep_var_col.
A power set of all possible exclusions of linear dependence on the given feature is created, i.e. if there are 4 features we end up with 2^4 possible models (for each model we independently decide whether to include or not a feature).
matrix of model parameters
library(magrittr)
data_prepared <- badp::economic_growth[, 1:5] %>%
badp::feature_standardization(
excluded_cols = c(country, year, gdp)
) %>%
badp::feature_standardization(
group_by_col = year,
excluded_cols = country,
scale = FALSE
)
init_model_space_params(data_prepared, year, country, gdp,
init_value = function(n) runif(n, 0.1, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.