model_sizes: Graphs of the prior and posterior model probabilities of the...

View source: R/model_sizes.R

model_sizesR Documentation

Graphs of the prior and posterior model probabilities of the model sizes

Description

This function draws two graphs of prior and posterior model probabilities:
a) The results with binomial model prior
b) The results with binomial-beta model prior
c) One graph combining all the aforementioned graphs

Usage

model_sizes(bma_list)

Arguments

bma_list

bma_list object (the result of the bma function)

Value

A list with three graphs with prior and posterior model probabilities for model sizes:

  1. The results with binomial model prior

  2. The results with binomial-beta model prior

  3. One graph combining all the aforementioned graphs

Examples


library(magrittr)

data_prepared <- badp::economic_growth[, 1:6] %>%
  badp::feature_standardization(
    excluded_cols = c(country, year, gdp)
  ) %>%
  badp::feature_standardization(
    group_by_col  = year,
    excluded_cols = country,
    scale         = FALSE
  )

bma_results <- bma(
  model_space = badp::small_model_space,
  round       = 3,
  dilution    = 0
)

size_graphs <- model_sizes(bma_results)


badp documentation built on Aug. 20, 2026, 9:08 a.m.