| model_sizes | R Documentation |
This function draws two graphs of prior and posterior model probabilities:
a) The results with binomial model prior
b) The results with binomial-beta model prior
c) One graph combining all the aforementioned graphs
model_sizes(bma_list)
bma_list |
bma_list object (the result of the bma function) |
A list with three graphs with prior and posterior model probabilities for model sizes:
The results with binomial model prior
The results with binomial-beta model prior
One graph combining all the aforementioned graphs
library(magrittr)
data_prepared <- badp::economic_growth[, 1:6] %>%
badp::feature_standardization(
excluded_cols = c(country, year, gdp)
) %>%
badp::feature_standardization(
group_by_col = year,
excluded_cols = country,
scale = FALSE
)
bma_results <- bma(
model_space = badp::small_model_space,
round = 3,
dilution = 0
)
size_graphs <- model_sizes(bma_results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.