| n_models | R Documentation |
Returns the number of models over which the averaging is performed. The
lagged dependent variable enters every model and is never averaged over, so
the count is two to the power of length(regressors(x)), not of the
total number of columns.
n_models(x, ...)
## S3 method for class 'badp_bma'
n_models(x, ...)
## S3 method for class 'badp_model_space'
n_models(x, ...)
x |
An object of class |
... |
Arguments passed to methods. |
A single integer.
bma, optim_model_space
data(full_model_space)
n_models(full_model_space)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.