| plot.badp_best_models | R Documentation |
Draws the inclusion table or the table of estimates for the selected models to the active graphics device.
## S3 method for class 'badp_best_models'
plot(x, which = c("estimates", "inclusion"), robust = FALSE, ...)
x |
An object of class |
which |
Which table to draw: |
robust |
Logical. If |
... |
Additional arguments (currently unused). |
Invisibly returns the drawn table.
best_models, print.badp_best_models
data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)
plot(best)
plot(best, which = "inclusion")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.