View source: R/s3_methods_bma.R
| plot.badp_bma | R Documentation |
Plot method for objects of class badp_bma.
## S3 method for class 'badp_bma'
plot(x, which = "model_sizes", ...)
x |
An object of class |
which |
Character string specifying which plot to create. Options are:
|
... |
Additional arguments passed to the underlying plot function. |
This function dispatches to the appropriate visualization function based on the
which parameter. The default plot shows model size distributions, which
provides a comprehensive overview of the prior and posterior distributions over
model sizes.
The object returned by the selected visualization helper. Depending on
which, this may be a single plot object or a list containing plots
and/or tables; some helpers may also print output as a side effect.
bma, model_sizes, best_models,
jointness, coef_hist, posterior_dens,
model_pmp
data(full_model_space)
results <- bma(full_model_space)
# Default plot (model sizes)
plot(results)
# Other plot types
plot(results, which = "best_models")
plot(results, which = "jointness")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.