| pmp | R Documentation |
Returns the posterior probability of each model in the model space.
pmp(x, ...)
## S3 method for class 'badp_bma'
pmp(x, prior = c("binomial", "beta"), top = NULL, ...)
x |
An object of class |
... |
Arguments passed to methods. |
prior |
Model prior: |
top |
Optional number of models to return, ordered by decreasing posterior probability. By default every model is returned, unsorted. |
A numeric vector of posterior model probabilities, one per model,
in the order in which the models are held in the model space unless
top is given.
pip, best_models,
model_pmp
data(full_model_space)
results <- bma(full_model_space)
sum(pmp(results)) # sums to one
pmp(results, top = 5) # the five most probable models
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.