View source: R/posterior_dens.R
| posterior_dens | R Documentation |
This function draws graphs of the posterior densities of all the coefficients of interest.
posterior_dens(bma_list, prior = "binomial", SE = "standard")
bma_list |
bma object (the result of the bma function) |
prior |
Parameter indicating which model prior should be used for calculations:
|
SE |
Parameter indicating which standard errors should be used in calculation of posterior standard deviation:
|
A list with the graphs of the posterior densities of coefficients for all the considered regressors.
library(magrittr)
data_prepared <- badp::economic_growth[, 1:6] %>%
badp::feature_standardization(
excluded_cols = c(country, year, gdp)
) %>%
badp::feature_standardization(
group_by_col = year,
excluded_cols = country,
scale = FALSE
)
bma_results <- bma(
model_space = badp::small_model_space,
round = 3,
dilution = 0
)
posterior_graphs <- posterior_dens(bma_results, prior = "binomial", SE = "robust")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.