| print.badp_best_models | R Documentation |
Prints, to the console, which regressors enter each of the selected models together with their posterior model probabilities.
## S3 method for class 'badp_best_models'
print(x, ...)
x |
An object of class |
... |
Additional arguments (currently unused). |
Invisibly returns x.
best_models,
summary.badp_best_models,
plot.badp_best_models
data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)
best
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.