| print.badp_model | R Documentation |
Prints the regressors included in one of the best models together with its posterior model probability and its coefficient table.
## S3 method for class 'badp_model'
print(x, robust = FALSE, ...)
x |
An object of class |
robust |
Logical. If |
... |
Additional arguments (currently unused). |
Invisibly returns x.
best_models, summary.badp_model
data(small_model_space)
best <- best_models(bma(small_model_space), best = 3)
best[[1]]
print(best[[1]], robust = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.