residual_maker_matrix: Residual maker matrix

View source: R/SEM_param_matrices.R

residual_maker_matrixR Documentation

Residual maker matrix

Description

Computes the residual maker matrix, i.e. a matrix M such that given a matrix X and a vector Y the vector of residuals from the regression of Y on X is given by M * Y

Usage

residual_maker_matrix(m)

Arguments

m

matrix based on which the residual maker matrix is built

Value

Residual maker matrix

Examples

residual_maker_matrix(matrix(c(1,2,3,4), nrow = 2))


badp documentation built on Aug. 20, 2026, 9:08 a.m.