View source: R/SEM_param_matrices.R
| residual_maker_matrix | R Documentation |
Computes the residual maker matrix, i.e. a matrix M such that given a matrix X and a vector Y the vector of residuals from the regression of Y on X is given by M * Y
residual_maker_matrix(m)
m |
matrix based on which the residual maker matrix is built |
Residual maker matrix
residual_maker_matrix(matrix(c(1,2,3,4), nrow = 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.