View source: R/SEM_param_matrices.R
| sem_C_matrix | R Documentation |
Matrix which describes linear dependencies between the dependent variable and the initial values of the dependent variable and the regressors within the SEM representation.
sem_C_matrix(alpha, phi_0, n_periods, beta = NULL, phi_1 = NULL)
alpha |
numeric |
phi_0 |
numeric |
n_periods |
integer |
beta |
numeric vector. Default is |
phi_1 |
numeric vector. Default is |
Matrix with linear dependencies for initial conditions
alpha <- 9
phi_0 <- 19
beta <- 11:15
phi_1 <- 21:25
n_periods <- 4
sem_C_matrix(alpha, phi_0, n_periods, beta, phi_1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.