View source: R/SEM_param_matrices.R
| sem_sigma_matrix | R Documentation |
Matrices which describe the covariance structure within the SEM representation.
sem_sigma_matrix(err_var, dep_vars, phis = NULL, psis = NULL)
err_var |
numeric error variance parameter |
dep_vars |
double vector with variance parameters of the dependent variable |
phis |
double vector with phi parameter values. Default is |
psis |
double vector with psi parameter values. Default is |
List with two matrices describing the covariance structure
err_var <- 1
dep_vars <- c(2, 2, 2, 2)
phis <- c(10, 10, 20, 20, 30, 30)
psis <- c(101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112)
sem_sigma_matrix(err_var, dep_vars, phis, psis)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.