| [.badp_best_models | R Documentation |
Keeps the class and the attributes of the selection when a subset of the models is taken.
## S3 method for class 'badp_best_models'
x[i]
x |
An object of class |
i |
Indices of the models to keep. |
An object of class badp_best_models.
data(small_model_space)
best <- best_models(bma(small_model_space), best = 5)
best[1:2] # a badp_best_models object holding the two best models
best[[1]] # a single badp_model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.